@@ -8,19 +8,18 @@
 #
 
 package POE::Component::Server::Discard;
+$POE::Component::Server::Discard::VERSION = '1.16';
+#ABSTRACT: A POE component that implements an RFC 863 Discard server.
 
 use strict;
 use warnings;
 use Carp;
 use POE;
 use base qw(POE::Component::Server::Echo);
-use vars qw($VERSION);
 
 use constant DATAGRAM_MAXLEN => 1024;
 use constant DEFAULT_PORT => 9;
 
-$VERSION = '1.14';
-
 sub _client_input {
   return;
 }
@@ -33,13 +32,22 @@ sub _get_datagram {
   undef;
 }
 
-1;
+qq[Throw it away, throw it away now];
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 POE::Component::Server::Discard - A POE component that implements an RFC 863 Discard server.
 
+=head1 VERSION
+
+version 1.16
+
 =head1 SYNOPSIS
 
  use POE::Component::Server::Discard;
@@ -62,7 +70,7 @@ L<POE>. It is a class inherited from L<POE::Component::Server::Echo>.
 
 =item C<spawn>
 
-Takes a number of optional values: 
+Takes a number of optional values:
 
   "Alias", the kernel alias that this component is to be blessed with; 
   "BindAddress", the address on the local host to bind to, defaults to 
@@ -78,16 +86,6 @@ Takes a number of optional values:
 
 Report any bugs through L<http://rt.cpan.org/>.
 
-=head1 AUTHOR
-
-Chris 'BinGOs' Williams, <chris@bingosnet.co.uk>
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE>
@@ -95,9 +93,20 @@ L<POE>
 L<POE::Session>
 
 L<POE::Wheel::SocketFactory>
- 
+
 L<POE::Component::Server::Echo>
 
 L<http://www.faqs.org/rfcs/rfc863.html>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Chris Williams.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
